# Generated by Django 3.2 on 2024-12-03 14:01

import chunked_field.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='MyModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('content', chunked_field.fields.ChunkedTextField()),
                ('json_data', chunked_field.fields.ChunkedTextField()),
            ],
        ),
    ]
