# Generated by Django 3.2 on 2024-12-03 14:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='DataChunk',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.PositiveIntegerField()),
                ('field_name', models.CharField(max_length=100)),
                ('sequence', models.PositiveIntegerField()),
                ('content', models.CharField(max_length=4000)),
                ('content_type',
                 models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
            options={
                'ordering': ['sequence'],
                'unique_together': {('content_type', 'object_id', 'field_name', 'sequence')},
            },
        ),
    ]
